Module util

Module util 

Functions

fetch_branch_if_aggressive
Run git fetch <branch> when aggressive is true; emit a warning on failure.
fetch_if_aggressive
Run git fetch --all when aggressive is true; emit a warning on failure.
prompt_yes_no
Print prompt, flush stdout, read one line, return true iff the answer is “y”.
worktree_for_ticket
Resolve a ticket ID argument to its worktree path and canonical ticket ID. Loads config and tickets from git internally.